# Launchpy

Python wrapper for the Adobe Launch API.
This module is name launchpy. You can actually copy it into your python3X/Lib folder so you can import it from anywhere in your module.

This module is built around 4 main parts:

- Intiating and helping functions (Core Components)
- Managing properties (Property Class)
- Managing Publishing Cycle (Library Class)
- Translator functionationality (Translator Class)

## Get Stated

A [get started guide](./docs/getstarted.md) has been created to explain the different functionality.
You can find a more detail description functionalities at [datanalyst.info](https://datanalyst.info).

~~A Jupyter notebook is also available in the github for demo.~~ To be updated.

## Main documentation

Most of the documentation has been imported from the datanalyst website [here](./docs/main.md).
